#!/sbin/itype
# This is a i file, used by initng parsed by install_service

# NAME:
# DESCRIPTION:
# WWW:

# This one should be ran first.
# Its purpose is to mount /proc and /sys.
service system/initial/mountvirtfs {
	critical;
	script start = {
		# test, if all necessary directories exist.
		if [ ! -d /proc -o ! -d /sys ]
		then
			echo "The /sys or /proc is missing, can't mount it!" >&2
			echo "Please sulogin, remount rw and create them." >&2
			exit 1 # It can't work. Critical!
		fi

		mount -n -t proc proc /proc &
		mount -n -t sysfs sys /sys &

		wait
		exit 0
	};
}

service system/initial/filldev {
	need = system/initial/mountvirtfs;
	use = system/udev/mountdev;
	critical; # This script can't be fail.
	script start = {
		echo "Mounting devpts at /dev/pts ..."
		/bin/mkdir -p /dev/pts &&
			/bin/mount -n -t devpts -o gid=5,mode=0620 none /dev/pts &

		echo "Mounting devshm at /dev/shm ..."
		/bin/mkdir -p /dev/shm &&
			/bin/mount -n -t tmpfs none /dev/shm &

		wait
		exit 0
	};
}

service system/initial/loglevel {
	# Set the console loglevel to 1 for a cleaner boot
	# the logger should anyhow dump the ring-0 buffer at start to the
	# logs, and that with dmesg can be used to check for problems
	exec start = /bin/dmesg -n 1;
	# Increase the debug level a bit
	exec stop = /bin/dmesg -n 2;
}

# This is the basic system/initial
virtual system/initial {
	critical;
	need = system/initial/loglevel system/initial/mountvirtfs system/initial/filldev;
	use = system/selinux/dev;
	use = system/udev;
}
