#!/sbin/itype
# This is a i file, used by initng parsed by install_service

# NAME:
# DESCRIPTION:
# WWW:

service system/mountfs/essential {
	need = system/initial/mountvirtfs system/mountroot system/checkfs;
	use = system/sraid system/hdparm system/selinux/relabel;
	critical;
	never_kill;

	script start = {
		for mp in /tmp /usr /var /srv /opt
		do
			/bin/mount -v "${mp}" 2>/dev/null &
		done
		wait
		exit 0
	};

	script stop = {
		echo "Sending all processes the TERM signal ..."
		/sbin/killalli5 -15
		sleep 3
		echo "Sending all processes the KILL signal ..."
		/sbin/killalli5 -9
		sleep 1

		MPS="$(
			while read d mp d
			do
				echo "${mp}"
			done < /proc/mounts | /bin/sort -r
		)"

		echo "${MPS}" | while read mp d
		do
			case "${mp}" in
			/|/proc|/sys|/dev*) ;;
			*)
				/usr/sbin/umount -r -d -f "${mp}"
				;;
			esac
		done
		exit 0
	};
}

service system/mountfs/home {
	need = system/mountroot system/checkfs;
	stderr = /dev/null;
	start_fail_ok;
	never_kill;

	exec start = /bin/mount -v /home;
}

service system/mountfs/network {
	need = system/initial system/mountfs/essential virtual/net;
	use = virtual/portmap;
	never_kill;
	env NET_FS = afs,cifs,coda,davfs,gfs,ncpfs,nfs,nfs4,ocfs2,shfs,smbfs;

	script start = {
		/bin/mount -a -v -F -t ${NET_FS} 2>/dev/null ||
			/bin/mount -a -v -t ${NET_FS}
	};

	exec stop = /usr/sbin/umount -a -f -t ${NET_FS};
}

service system/mountfs {
	need = system/mountfs/essential system/mountfs/home;
	use = system/mountfs/network;
	env LOCAL_FS = reiserfs,reiser4,reiserfs,reiser4,ext2,ext3,xfs,jfs,vfat,ntfs,ntfs-3g,tmpfs,subfs,bind,auto;
	never_kill;

	script start = {
		/bin/mount -a -F -v -t ${LOCAL_FS} 2>/dev/null ||
		/bin/mount -a -v -t ${LOCAL_FS}
		exit 0
	};
}
